==> deprecated-in-v4-jvm-4.1.0-sources.jar: jvmMain/jetbrains/datalore/vis/swing/depracetedSymbols.kt <==
/*
 * Copyright (c) 2023. JetBrains s.r.o.
 * Use of this source code is governed by the MIT license that can be found in the LICENSE file.
 */

package jetbrains.datalore.vis.swing

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.PlotComponentProvider"), level = DeprecationLevel.WARNING
)
typealias PlotComponentProvider = org.jetbrains.letsPlot.awt.plot.component.PlotComponentProvider

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.PlotPanel"), level = DeprecationLevel.WARNING
)
typealias PlotPanel = org.jetbrains.letsPlot.awt.plot.component.PlotPanel

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.ApplicationContext"), level = DeprecationLevel.WARNING
)
typealias ApplicationContext = org.jetbrains.letsPlot.awt.plot.component.ApplicationContext

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.DefaultPlotContentPane"), level = DeprecationLevel.WARNING
)
typealias DefaultPlotContentPane = org.jetbrains.letsPlot.awt.plot.component.DefaultPlotContentPane

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.PlotViewerWindowBase"), level = DeprecationLevel.WARNING
)
typealias PlotViewerWindowBase = org.jetbrains.letsPlot.awt.plot.component.PlotViewerWindowBase

==> deprecated-in-v4-jvm-4.5.1-sources.jar: jvmMain/jetbrains/datalore/vis/swing/depracetedSymbols.kt <==
/*
 * Copyright (c) 2023. JetBrains s.r.o.
 * Use of this source code is governed by the MIT license that can be found in the LICENSE file.
 */

package jetbrains.datalore.vis.swing

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.PlotComponentProvider"), level = DeprecationLevel.ERROR
)
typealias PlotComponentProvider = org.jetbrains.letsPlot.awt.plot.component.PlotComponentProvider

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.PlotPanel"), level = DeprecationLevel.ERROR
)
typealias PlotPanel = org.jetbrains.letsPlot.awt.plot.component.PlotPanel

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.ApplicationContext"), level = DeprecationLevel.ERROR
)
typealias ApplicationContext = org.jetbrains.letsPlot.awt.plot.component.ApplicationContext

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.DefaultPlotContentPane"), level = DeprecationLevel.ERROR
)
typealias DefaultPlotContentPane = org.jetbrains.letsPlot.awt.plot.component.DefaultPlotContentPane

@Deprecated(
    "Moved to package \"org.jetbrains.letsPlot.awt.plot.component\"",
    ReplaceWith("org.jetbrains.letsPlot.awt.plot.component.PlotViewerWindowBase"), level = DeprecationLevel.ERROR
)
typealias PlotViewerWindowBase = org.jetbrains.letsPlot.awt.plot.component.PlotViewerWindowBase
